import { date as qdate, format } from 'quasar'
const { pad } = format

export function currency (val) {
    return typeof val === 'number' ? val.toFixed(2) + '€' : val
}

export function date (val, format) {
    if (val == null) return val
    if (!(val instanceof Date)) {
        val = new Date(val)
    }
    return qdate.formatDate(val, format, window.i18n.tm('date'))
}

export function relDate (val) {
    if (val == null) return val
    if (!(val instanceof Date)) {
        val = new Date(val)
    }

    const dif = qdate.getDateDiff(new Date(), val, 'days')
    let day

    switch (dif) {
        case 0:
            day = 'today'
            break
        case 1:
            day = 'yesterday'
            break
        case -1:
            day = 'tomorrow'
            break
    }

    if (day) {
        day = window.i18n.t(day)
    } else {
        if (dif > 0 && dif <= 7) {
            day = qdate.formatDate(val, 'ddd', window.i18n.tm('date'))
        } else {
            day = qdate.formatDate(val, 'ddd, MMMM Do', window.i18n.tm('date'))
        }
    }

    return day
}

export function relTime (val) {
    if (val == null) return val
    if (!(val instanceof Date)) {
        val = new Date(val)
    }
    return relDate(val) + ' ' + qdate.formatDate(val, 'H:mm:ss')
}

export function elapsedTime (val) {
    if (val == null) return val
    if (!(val instanceof Date)) {
        val = new Date(val)
    }
    const now = new Date().getTime()
    val = Math.floor((now - val.getTime()) / 1000)

    const hours = Math.floor(val / 3600)
    val -= hours * 3600
    const minutes = Math.floor(val / 60)
    val -= minutes * 60
    const seconds = val

    return `${pad(hours, 2)}:${pad(minutes, 2)}:${pad(seconds, 2)}`
}
